==> huaweicloudsdkdns-3.1.16-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/batch_delete_record_sets_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteRecordSetsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'recordsets': 'list[RecordsetData]',
        'metadata': 'Metedata'
    }

    attribute_map = {
        'recordsets': 'recordsets',
        'metadata': 'metadata'
    }

    def __init__(self, recordsets=None, metadata=None):
        """BatchDeleteRecordSetsResponse

        The model defined in huaweicloud sdk

        :param recordsets: 待删除zone类型，当前仅支持 public 或 private
        :type recordsets: list[:class:`huaweicloudsdkdns.v2.RecordsetData`]
        :param metadata: 
        :type metadata: :class:`huaweicloudsdkdns.v2.Metedata`
        """
        
        super(BatchDeleteRecordSetsResponse, self).__init__()

        self._recordsets = None
        self._metadata = None
        self.discriminator = None

        if recordsets is not None:
            self.recordsets = recordsets
        if metadata is not None:
            self.metadata = metadata

    @property
    def recordsets(self):
        """Gets the recordsets of this BatchDeleteRecordSetsResponse.

        待删除zone类型，当前仅支持 public 或 private

        :return: The recordsets of this BatchDeleteRecordSetsResponse.
        :rtype: list[:class:`huaweicloudsdkdns.v2.RecordsetData`]
        """
        return self._recordsets

    @recordsets.setter
    def recordsets(self, recordsets):
        """Sets the recordsets of this BatchDeleteRecordSetsResponse.

        待删除zone类型，当前仅支持 public 或 private

        :param recordsets: The recordsets of this BatchDeleteRecordSetsResponse.
        :type recordsets: list[:class:`huaweicloudsdkdns.v2.RecordsetData`]
        """
        self._recordsets = recordsets

    @property
    def metadata(self):
        """Gets the metadata of this BatchDeleteRecordSetsResponse.

        :return: The metadata of this BatchDeleteRecordSetsResponse.
        :rtype: :class:`huaweicloudsdkdns.v2.Metedata`
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this BatchDeleteRecordSetsResponse.

        :param metadata: The metadata of this BatchDeleteRecordSetsResponse.
        :type metadata: :class:`huaweicloudsdkdns.v2.Metedata`
        """
        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteRecordSetsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdns-3.1.20-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/batch_delete_record_sets_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteRecordSetsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'recordsets': 'list[RecordsetData]',
        'metadata': 'Metadata'
    }

    attribute_map = {
        'recordsets': 'recordsets',
        'metadata': 'metadata'
    }

    def __init__(self, recordsets=None, metadata=None):
        """BatchDeleteRecordSetsResponse

        The model defined in huaweicloud sdk

        :param recordsets: 待删除zone类型，当前仅支持public或private。
        :type recordsets: list[:class:`huaweicloudsdkdns.v2.RecordsetData`]
        :param metadata: 
        :type metadata: :class:`huaweicloudsdkdns.v2.Metadata`
        """
        
        super(BatchDeleteRecordSetsResponse, self).__init__()

        self._recordsets = None
        self._metadata = None
        self.discriminator = None

        if recordsets is not None:
            self.recordsets = recordsets
        if metadata is not None:
            self.metadata = metadata

    @property
    def recordsets(self):
        """Gets the recordsets of this BatchDeleteRecordSetsResponse.

        待删除zone类型，当前仅支持public或private。

        :return: The recordsets of this BatchDeleteRecordSetsResponse.
        :rtype: list[:class:`huaweicloudsdkdns.v2.RecordsetData`]
        """
        return self._recordsets

    @recordsets.setter
    def recordsets(self, recordsets):
        """Sets the recordsets of this BatchDeleteRecordSetsResponse.

        待删除zone类型，当前仅支持public或private。

        :param recordsets: The recordsets of this BatchDeleteRecordSetsResponse.
        :type recordsets: list[:class:`huaweicloudsdkdns.v2.RecordsetData`]
        """
        self._recordsets = recordsets

    @property
    def metadata(self):
        """Gets the metadata of this BatchDeleteRecordSetsResponse.

        :return: The metadata of this BatchDeleteRecordSetsResponse.
        :rtype: :class:`huaweicloudsdkdns.v2.Metadata`
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this BatchDeleteRecordSetsResponse.

        :param metadata: The metadata of this BatchDeleteRecordSetsResponse.
        :type metadata: :class:`huaweicloudsdkdns.v2.Metadata`
        """
        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteRecordSetsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
